Build-time helpers for compiling magic rules.
This module contains functionality used by the build script to parse magic files and generate Rust code for built-in rules. It is only available during tests and documentation builds to enable comprehensive testing of the build process.
Functions
- format_
parse_ error - Formats a parse error for display in build script output.
- parse_
and_ generate_ builtin_ rules - Parses a magic file and generates Rust code for the built-in rules.