Module types

Module types 

Type interpretation for reading and converting bytes from file buffers.

This module exposes the public type-reading API and dispatches to focused submodules for numeric and string handling.

Enums

TypeReadError
Errors that can occur during type reading operations.

Functions

coerce_value_to_type
Coerces a rule value to the signed width implied by type_kind.
read_byte
Safely reads a single byte from the buffer at the specified offset.
read_double
Safely reads a 64-bit IEEE 754 double from the buffer at the specified offset.
read_float
Safely reads a 32-bit IEEE 754 float from the buffer at the specified offset.
read_long
Safely reads a 32-bit integer from the buffer at the specified offset.
read_quad
Safely reads a 64-bit integer from the buffer at the specified offset.
read_short
Safely reads a 16-bit integer from the buffer at the specified offset.
read_string
Safely reads a null-terminated string from the buffer at the specified offset.
read_typed_value
Reads bytes according to the specified TypeKind.