Module mime

Module mime 

MIME type mapping for file type detection

This module provides MIME type mapping from file type descriptions to standard MIME types. It includes hardcoded mappings for common file types.

Structs

MimeMapper
MIME type mapper for converting file descriptions to MIME types