Type interpretation for reading and converting bytes from file buffers.
This module exposes the public type-reading API and dispatches to focused submodules for numeric and string handling.
Enums
- Type
Read Error - Errors that can occur during type reading operations.
Functions
- coerce_
value_ to_ type - Coerces a rule value to the signed width implied by
type_kind. - read_
byte - Safely reads a single byte from the buffer at the specified offset.
- read_
double - Safely reads a 64-bit IEEE 754 double from the buffer at the specified offset.
- read_
float - Safely reads a 32-bit IEEE 754 float from the buffer at the specified offset.
- read_
long - Safely reads a 32-bit integer from the buffer at the specified offset.
- read_
quad - Safely reads a 64-bit integer from the buffer at the specified offset.
- read_
short - Safely reads a 16-bit integer from the buffer at the specified offset.
- read_
string - Safely reads a null-terminated string from the buffer at the specified offset.
- read_
typed_ value - Reads bytes according to the specified
TypeKind.