Module types

Module types 

Type interpretation for reading and converting bytes from file buffers.

This module exposes the public type-reading API and dispatches to focused submodules for numeric and string handling.

Enums

TypeReadError
Errors that can occur during type reading operations.